@@ -42,7 +42,7 @@ var searchData=
   ['com_5fsun_5fstar_5fchart2_5fdata_5fxsheetdataprovider_5fidl_39',['com_sun_star_chart2_data_XSheetDataProvider_idl',['../XSheetDataProvider_8idl.html#a0dc5430ac2e843e2ad0baa9b19570297',1,'XSheetDataProvider.idl']]],
   ['com_5fsun_5fstar_5fchart2_5fdata_5fxtextualdatasequence_5fidl_40',['com_sun_star_chart2_data_XTextualDataSequence_idl',['../XTextualDataSequence_8idl.html#a0d61f34109037f2168ce9bad2c796762',1,'XTextualDataSequence.idl']]],
   ['com_5fsun_5fstar_5fchart2_5fdatapoint_5fidl_41',['com_sun_star_chart2_DataPoint_idl',['../DataPoint_8idl.html#ad973cc564364f6ead3744a770dd0fb72',1,'DataPoint.idl']]],
-  ['com_5fsun_5fstar_5fchart2_5fdatapointcustomlabelfield_5fidl_42',['com_sun_star_chart2_DataPointCustomLabelField_idl',['../DataPointCustomLabelField_8idl.html#a549d868fd1f1e22186be34f0e42c2339',1,'com_sun_star_chart2_DataPointCustomLabelField_idl():&#160;DataPointCustomLabelField.idl'],['../XDataPointCustomLabelField_8idl.html#a549d868fd1f1e22186be34f0e42c2339',1,'com_sun_star_chart2_DataPointCustomLabelField_idl():&#160;XDataPointCustomLabelField.idl']]],
+  ['com_5fsun_5fstar_5fchart2_5fdatapointcustomlabelfield_5fidl_42',['com_sun_star_chart2_DataPointCustomLabelField_idl',['../DataPointCustomLabelField_8idl.html#a549d868fd1f1e22186be34f0e42c2339',1,'com_sun_star_chart2_DataPointCustomLabelField_idl:&#160;DataPointCustomLabelField.idl'],['../XDataPointCustomLabelField_8idl.html#a549d868fd1f1e22186be34f0e42c2339',1,'com_sun_star_chart2_DataPointCustomLabelField_idl:&#160;XDataPointCustomLabelField.idl']]],
   ['com_5fsun_5fstar_5fchart2_5fdatapointcustomlabelfieldtype_5fidl_43',['com_sun_star_chart2_DataPointCustomLabelFieldType_idl',['../DataPointCustomLabelFieldType_8idl.html#a077d23e44d85f1487f0503a473cf0eee',1,'DataPointCustomLabelFieldType.idl']]],
   ['com_5fsun_5fstar_5fchart2_5fdatapointlabel_5fidl_44',['com_sun_star_chart2_DataPointLabel_idl',['../DataPointLabel_8idl.html#ab4afacbfa54dff2916704d16294efecf',1,'DataPointLabel.idl']]],
   ['com_5fsun_5fstar_5fchart2_5fdatapointproperties_5fidl_45',['com_sun_star_chart2_DataPointProperties_idl',['../DataPointProperties_8idl.html#ab15c92d1ce47bf6f556906e1fdf46c39',1,'DataPointProperties.idl']]],
