@@ -3,14 +3,14 @@ var searchData=
   ['k_0',['K',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html#a19359316f58dda97c1ab163e3a7b0dbd',1,'com::sun::star::awt::Key']]],
   ['keep_1',['KEEP',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1NameClash.html#a28e859852ecabe5a1de9e0d2d9a69df3',1,'com::sun::star::ucb::NameClash']]],
   ['keepformats_2',['KeepFormats',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ac34b74170aee53aa1f3898b38f5ac393',1,'com::sun::star::sheet::DatabaseRange']]],
-  ['keeptogether_3',['KeepTogether',['../interfacecom_1_1sun_1_1star_1_1report_1_1XGroup.html#a8c23ee90f1673324ebe9be853d698d0b',1,'com::sun::star::report::XGroup::KeepTogether()'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XSection.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::report::XSection::KeepTogether()'],['../servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::text::TextTable::KeepTogether()']]],
+  ['keeptogether_3',['KeepTogether',['../interfacecom_1_1sun_1_1star_1_1report_1_1XGroup.html#a8c23ee90f1673324ebe9be853d698d0b',1,'com::sun::star::report::XGroup::KeepTogether'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XSection.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::report::XSection::KeepTogether'],['../servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::text::TextTable::KeepTogether']]],
   ['kerning_4',['Kerning',['../structcom_1_1sun_1_1star_1_1awt_1_1FontDescriptor.html#aa6eda54d871903b98a22c0b1db0630f7',1,'com::sun::star::awt::FontDescriptor']]],
   ['key_5fagreement_5',['KEY_AGREEMENT',['../namespacecom_1_1sun_1_1star_1_1security_1_1KeyUsage.html#aa122bee0e332805fdeba43e6d951c17e',1,'com::sun::star::security::KeyUsage']]],
   ['key_5fcert_5fsign_6',['KEY_CERT_SIGN',['../namespacecom_1_1sun_1_1star_1_1security_1_1KeyUsage.html#a463ae94ba5bd24621488cb5435b1eff0',1,'com::sun::star::security::KeyUsage']]],
   ['key_5fencipherment_7',['KEY_ENCIPHERMENT',['../namespacecom_1_1sun_1_1star_1_1security_1_1KeyUsage.html#a61450b1151c9b77bcb2c0fc89e53998d',1,'com::sun::star::security::KeyUsage']]],
-  ['keychar_8',['KeyChar',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#a2ebeaada4dee647dafd1cd26ea1a60c7',1,'com::sun::star::awt::KeyStroke::KeyChar()'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#a2ebeaada4dee647dafd1cd26ea1a60c7',1,'com::sun::star::awt::KeyEvent::KeyChar()']]],
-  ['keycode_9',['KeyCode',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#ac52fee1e96933f6d99789b325933a7ab',1,'com::sun::star::awt::KeyStroke::KeyCode()'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#ac52fee1e96933f6d99789b325933a7ab',1,'com::sun::star::awt::KeyEvent::KeyCode()']]],
-  ['keyfunc_10',['KeyFunc',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#a607ef284179388eaf7163586eaccafa4',1,'com::sun::star::awt::KeyStroke::KeyFunc()'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#a607ef284179388eaf7163586eaccafa4',1,'com::sun::star::awt::KeyEvent::KeyFunc()']]],
+  ['keychar_8',['KeyChar',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#a2ebeaada4dee647dafd1cd26ea1a60c7',1,'com::sun::star::awt::KeyStroke::KeyChar'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#a2ebeaada4dee647dafd1cd26ea1a60c7',1,'com::sun::star::awt::KeyEvent::KeyChar']]],
+  ['keycode_9',['KeyCode',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#ac52fee1e96933f6d99789b325933a7ab',1,'com::sun::star::awt::KeyStroke::KeyCode'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#ac52fee1e96933f6d99789b325933a7ab',1,'com::sun::star::awt::KeyEvent::KeyCode']]],
+  ['keyfunc_10',['KeyFunc',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#a607ef284179388eaf7163586eaccafa4',1,'com::sun::star::awt::KeyStroke::KeyFunc'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#a607ef284179388eaf7163586eaccafa4',1,'com::sun::star::awt::KeyEvent::KeyFunc']]],
   ['keyhole_11',['KEYHOLE',['../namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#ac8c11e631b64563c2927cd482e0e357d',1,'com::sun::star::animations::TransitionSubType']]],
   ['keyname_12',['KeyName',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad75286a69f558484322dac5297e2ed64',1,'com::sun::star::registry::XRegistryKey']]],
   ['keytype_13',['KeyType',['../interfacecom_1_1sun_1_1star_1_1container_1_1XMap.html#a30f2a87e0c20d8c997a6de03a3959683',1,'com::sun::star::container::XMap']]],
